/*=======================================
 MS EXPERMIENT ANALYSIS FILE
 =======================================*/

* Load data
use "Data/Data_2014MSIntVoters_Exp.dta", clear

* Define macro storing list of covariates
global covs i_age age_miss d_sex_female d_sex_unknown d_race_black d_race_othdk d_vh2 d_vh3 d_vh4 d_vh5 d_vh6 d_vh7 d_vh8 d_vh9 d_vh10 d_vh11 d_vh12 d_vh13 d_vh14 d_vh15 d_vh16 d_vh17 d_vh18 d_vh19 d_vh20 d_vh21 d_vh22

* IPWs (pos/neg/control)
gen t_pnc = "c"
replace t_pnc = "p" if t_posnorms == 1
replace t_pnc = "n" if t_negnorms == 1
tab t_pnc, m
tab t_pnc t_posnorms, m
tab t_pnc t_negnorms, m
local nobs = _N
preserve
contract t_pnc, freq(freq) percent(pct)
gen ipw_pnc = 1/(pct/100)
list, t
drop freq pct
save "ipw_pnc.dta", replace
restore
merge m:1 t_pnc using "ipw_pnc.dta"
drop _merge
erase "ipw_pnc.dta"
des

/* MAIN SPECIFICATION */

local diffestlab = "Estimated Diff. in Mean Effects: Positive - Negative Social Pressure"
local diffselab = "Estimated SE, Diff. in Mean Effects: Positive - Negative Social Pressure"
local diffplab = "P-Value: Null Hypothesis that Diff. in Mean Effects of Positive and Negative Social Pressure is Zero"

* Code to capture estimates (cov adjusted w/ weighting) to plot as a figure
capture erase "Data/MS_Estimates.dta"
tempname tempfile
postfile `tempfile' b_pos se_pos b_neg se_neg b_diff se_diff using "Data/MS_Estimates.dta"

* Weighted, covariate adjusted
reg voted14_gen t_posnorms t_negnorms $covs [aweight=ipw_pnc], robust
qui sum voted14_gen [aweight=ipw_pnc] if e(sample) & t_pnc == "c"
local c_mean = r(mean)
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
outreg2 using "Tables/Table_A8.out", replace dec(3) label keep(t_posnorms t_negnorms) ///
	ctitle("Weighted and,with Covariates") ///
	addstat("Control Group Mean Turnout", `c_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", Y, "With Covariates?", Y)

* Save estimates
post `tempfile' (_b[t_posnorms]) (_se[t_posnorms]) (_b[t_negnorms]) (_se[t_negnorms]) (`diff_est') (`diff_se')
postclose `tempfile'
	
/* SENSITIVITY CHECKS */

* Weighted, unadjusted
reg voted14_gen t_posnorms t_negnorms [aweight=ipw_pnc], robust
qui sum voted14_gen [aweight=ipw_pnc] if e(sample) & t_pnc == "c"
local c_mean = r(mean)
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
outreg2 using "Tables/Table_A8.out", append dec(3) label keep(t_posnorms t_negnorms) ///
	ctitle("Weighted and,without Covariates") ///
	addstat("Control Group Mean Turnout", `c_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", Y, "With Covariates?", N)

* Unweighted, covariate adjusted
reg voted14_gen t_posnorms t_negnorms $covs, robust
qui sum voted14_gen if e(sample) & t_pnc == "c"
local c_mean = r(mean)
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
outreg2 using "Tables/Table_A8.out", append dec(3) label keep(t_posnorms t_negnorms) ///
	ctitle("Not Weighted and,with Covariates") ///
	addstat("Control Group Mean Turnout", `c_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", N, "With Covariates?", Y)

* Unweighted, unadjusted
reg voted14_gen t_posnorms t_negnorms, robust
qui sum voted14_gen if e(sample) & t_pnc == "c"
local c_mean = r(mean)
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
outreg2 using "Tables/Table_A8.out", append dec(3) label keep(t_posnorms t_negnorms) ///
	ctitle("Not Weighted and,without Covariates") ///
	addstat("Control Group Mean Turnout", `c_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", N, "With Covariates?", N)


/* N BY TREATMENT ARM */

* drop t_pnc, re-create variable as numeric instead and lbel
drop t_pnc
gen t_pnc = 0
replace t_pnc = 1 if t_posnorms == 1
replace t_pnc = 2 if t_negnorms == 1

label var t_pnc "Treatment Arm"
label define t_pnc_lab 0 "Control" 1 "Positive Social Pressure" 2 "Negative Social Pressure"
label values t_pnc t_pnc_lab
tabout t_pnc using "Tables/Table_A9.out", cells(freq col) f(0c 2c) oneway replace

/* RANDOMIZATION CHECKS */

mlogit t_pnc $covs , base(0) nolog
outreg2 using "Tables/Table_A10.out", replace dec(3) aster(se) label keep($covs) addstat("LR Test Chi-Square", e(chi2), "p-value", e(p))

/* BALANCE TABLES */


* Unweighted
/*
forv z = 0(1)2 {
	if `z' == 0 {
		local clabel = "Control"
		outsum $covs using "Tables/MS_BalanceTable_Unweighted.out" if t_pnc == `z' , bracket ctitle("`clabel'") replace
	}
	else {
		if `z' == 1 {
			local clabel = "Positive Social Pressure"
		}
		else {
			local clabel = "Negative Social Pressure"
		}
		outsum $covs using "Tables/MS_BalanceTable_Unweighted.out" if t_pnc == `z' , bracket ctitle("`clabel'") append
	}
}
*/

* Weighted
forv z = 0(1)2 {
	if `z' == 0 {
		local clabel = "Control"
		outsum $covs [aweight=ipw_pnc] using "Tables/Table_A11.out" if t_pnc == `z' , bracket ctitle("`clabel'") replace
	}
	else {
		if `z' == 1 {
			local clabel = "Positive Social Pressure"
		}
		else {
			local clabel = "Negative Social Pressure"
		}
		outsum $covs [aweight=ipw_pnc] using "Tables/Table_A11.out" if t_pnc == `z' , bracket ctitle("`clabel'") append
	}
}


/*---------------------------------------------------------- 
 PREP DATA TO PLOT IN R
 ----------------------------------------------------------*/
 
use "Data/MS_Estimates.dta", clear
gen id = _n
reshape long b_ se_ , i(id) j(var) s
rename b_ b
rename se_ se
gen qi = 0
replace qi = 1 if var == "pos"
replace qi = 2 if var == "neg"
replace qi = 3 if var == "diff"
drop id
* Save data
compress
outsheet using "Data/MS_Estimates_for_R.csv", replace comma
erase "Data/MS_Estimates.dta"
